package de.jottyfan.timetrack.spring;

import java.time.Duration;
import java.time.LocalDate;
import java.util.List;

import javax.annotation.security.RolesAllowed;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;

import de.jottyfan.timetrack.spring.done.DoneBean;
import de.jottyfan.timetrack.spring.done.DoneModel;
import de.jottyfan.timetrack.spring.done.IDoneService;
import de.jottyfan.timetrack.spring.done.SummaryBean;

/**
 * 
 * @author henkej
 *
 */
@Controller
public class IndexController {
	private static final Logger LOGGER = LogManager.getLogger(IndexController.class);

	private final HttpServletRequest request;

	@Autowired
	private IDoneService doneService;

	@Autowired
	public IndexController(HttpServletRequest request) {
		this.request = request;
	}

	@GetMapping("/logout")
	public String getLogout(HttpServletRequest request) throws ServletException {
		request.logout();
		return "redirect:/";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping("/")
	public String getIndex(@ModelAttribute DoneModel doneModel, Model model) {
		String username = doneService.getCurrentUser(request);
		Duration maxWorkTime = Duration.ofHours(8); // TODO: to the configuration file
		LocalDate day = LocalDate.now();
		List<DoneBean> list = doneService.getList(day, username);
		model.addAttribute("sum", new SummaryBean(list, day, maxWorkTime));
		LOGGER.debug("sum = {}", model.getAttribute("sum"));
		return "public/index";
	}
}
